@@ -1,6 +1,7 @@
 """
 undictify - Type-checked function calls at runtime
 """
+import collections
 import enum
 import inspect
 from dataclasses import InitVar, is_dataclass
@@ -82,10 +83,10 @@ def type_checked_constructor(skip: bool = False,
         if signature_new_param_names != ['args', 'kwargs']:
             func.__new__ = wrapper(func.__new__, signature_new)  # type: ignore
         else:
-            func.__init__ = wrapper(func.__init__, _get_signature(func.__init__))  # type: ignore
+            func.__init__ = wrapper(func.__init__, _get_signature(func.__init__))
             if is_dataclass(func) and hasattr(func, '__post_init__'):
-                func.__post_init__ = wrapper(func.__post_init__,  # type: ignore
-                                             _get_signature(func.__post_init__))  # type: ignore
+                func.__post_init__ = wrapper(func.__post_init__,
+                                             _get_signature(func.__post_init__))
         setattr(func, '__undictify_wrapped_func__', func)
         return func
 
@@ -253,7 +254,7 @@ def _get_value(func: WrappedOrFunc[TypeT],
         if _is_optional_type(func) or _is_union_type(func) \
         else [func]))
 
-    if func is inspect.Parameter.empty and param_name != 'self':
+    if func is inspect.Parameter.empty and param_name != 'self':  # type: ignore
         raise TypeError(f'Parameter {param_name} of target function '
                         'is missing a type annotation.')
 
@@ -274,6 +275,11 @@ def _get_value(func: WrappedOrFunc[TypeT],
                     if value == entry.value:
                         return entry
                 raise TypeError(f'Unable to instantiate {func} from {value}.')
+            if _is_optional_enum_type(func):
+                for entry in _get_optional_type(func):  # type: ignore
+                    if value == entry.value:
+                        return entry
+                raise TypeError(f'Unable to instantiate {func} from {value}.')
             if optional_converters and param_name in optional_converters:
                 result = optional_converters[param_name](value)
                 if not _isinstanceofone(result, allowed_types):
@@ -323,8 +329,8 @@ def _get_list_value(func: Callable[..., TypeT],  # pylint: disable=too-many-argu
                     value: Any, log_name: str,
                     skip_superfluous: bool, convert_types: bool,
                     converters: TaggedConverters) -> Any:
-    if not _is_list_type(func) and \
-            not _is_optional_list_type(func):
+    if not _is_list_ish_type(func) and \
+            not _is_optional_list_ish_type(func):
         raise TypeError(f'No list expected for {log_name}')
     result = []
     result_elem_type = _get_list_type_elem_type(func)
@@ -341,7 +347,7 @@ def _get_dict_value(func: Callable[..., TypeT], value: Any,
                     converters: TaggedConverters) -> Any:
     assert _is_dict(value)
     if _is_optional_type(func):
-        return _get_optional_type(func)(**value)  # type: ignore
+        return _get_optional_type(func)(**value)
     if _is_dict_type(func):
         key_type = _get_dict_key_type(func)
         value_type = _get_dict_value_type(func)
@@ -378,21 +384,23 @@ def _is_union_type(the_type: Callable[..., TypeT]) -> bool:
             _is_instance(the_type, _GenericAlias) and _type_origin_is(the_type, Union))
 
 
-def _is_list_type(the_type: Callable[..., TypeT]) -> bool:
+def _is_list_ish_type(the_type: Callable[..., TypeT]) -> bool:
     """Return True if the type is a List."""
     try:
-        return _is_instance(the_type,
-                            _GenericAlias) and _type_origin_is(the_type, list)
+        return (_is_instance(the_type, _GenericAlias) and
+                _type_origin_is(the_type, list) or
+                _is_instance(the_type, _GenericAlias) and
+                _type_origin_is(the_type, collections.abc.Sequence))
     except TypeError:
         return False
 
 
-def _is_optional_list_type(the_type: Callable[..., TypeT]) -> bool:
+def _is_optional_list_ish_type(the_type: Callable[..., TypeT]) -> bool:
     """Return True if the type is a Optional[List]."""
-    if _is_list_type(the_type):
+    if _is_list_ish_type(the_type):
         return True
     if _is_optional_type(the_type) and \
-            _is_list_type(_get_optional_type(the_type)):
+            _is_list_ish_type(_get_optional_type(the_type)):
         return True
     return False
 
@@ -448,7 +456,7 @@ def _get_type_name(the_type: Callable[..., TypeT]) -> str:
     if _is_union_type(the_type):
         union_type_names = [t.__name__ for t in _get_union_types(the_type)]
         return f'Union[{", ".join(union_type_names)}]'
-    if _is_list_type(the_type):
+    if _is_list_ish_type(the_type):
         return f'List[{str(_get_list_type_elem_type(the_type).__name__)}]'
     return the_type.__name__
 
@@ -457,7 +465,7 @@ def _get_list_type_elem_type(list_type: Callable[..., TypeT]) -> Callable[..., A
     """Return the type of a single element of the list type."""
     if _is_optional_type(list_type):
         list_type = _get_optional_type(list_type)
-    assert _is_list_type(list_type)
+    assert _is_list_ish_type(list_type)
     list_args = list_type.__args__  # type: ignore
     assert len(list_args) == 1
     return list_args[0]  # type: ignore
@@ -495,6 +503,11 @@ def _is_enum_type(the_type: Callable[..., TypeT]) -> bool:
         return False
 
 
+def _is_optional_enum_type(the_type: Callable[..., TypeT]) -> bool:
+    """Return True if the type is an Optional[Enum]."""
+    return _is_optional_type(the_type) and _is_enum_type(_get_optional_type(the_type))
+
+
 def _is_union_of_builtins_type(the_type: Callable[..., TypeT]) -> bool:
     """Return True if the type is an Union only made of
     None, str, int, float and bool."""
