@@ -7,7 +7,7 @@ import json
 import pickle
 import unittest
 from datetime import datetime
-from typing import Any, Callable, Dict, List, NamedTuple, Optional, Union, Tuple
+from typing import Any, Callable, Dict, List, NamedTuple, Optional, Union, Tuple, Sequence
 from typing import TypeVar
 
 from ._unpack import optional_converter, mandatory_converter
@@ -1426,6 +1426,24 @@ class WithAutoEnum(NamedTuple):
     auto_enum: SomeAutoEnum
 
 
+@type_checked_constructor()
+class WithOptionalIntEnum(NamedTuple):
+    """Some dummy class with int enum."""
+    int_enum: Optional[SomeIntEnum]
+
+
+@type_checked_constructor()
+class WithOptionalStrEnum(NamedTuple):
+    """Some dummy class with str enum."""
+    str_enum: Optional[SomeStrEnum]
+
+
+@type_checked_constructor()
+class WithOptionalAutoEnum(NamedTuple):
+    """Some dummy class with auto enum."""
+    auto_enum: Optional[SomeAutoEnum]
+
+
 class TestWithEnums(unittest.TestCase):
     """Enums should work too"""
 
@@ -1453,6 +1471,24 @@ class TestWithEnums(unittest.TestCase):
         obj = WithAutoEnum(**json.loads(object_repr))
         self.assertEqual(SomeAutoEnum.FOO, obj.auto_enum)
 
+    def test_optional_int_enum(self) -> None:
+        """Valid JSON string."""
+        object_repr = '''{"int_enum": 2}'''
+        obj = WithOptionalIntEnum(**json.loads(object_repr))
+        self.assertEqual(SomeIntEnum.BAR, obj.int_enum)
+
+    def test_optional_str_enum(self) -> None:
+        """Valid JSON string."""
+        object_repr = '''{"str_enum": "NOTEXACTLYBAR"}'''
+        obj = WithOptionalStrEnum(**json.loads(object_repr))
+        self.assertEqual(SomeStrEnum.BAR, obj.str_enum)
+
+    def test_optional_auto_enum(self) -> None:
+        """Valid JSON string."""
+        object_repr = '''{"auto_enum": ''' + str(SomeAutoEnum.FOO.value) + '''}'''
+        obj = WithOptionalAutoEnum(**json.loads(object_repr))
+        self.assertEqual(SomeAutoEnum.FOO, obj.auto_enum)
+
 
 @type_checked_constructor(convert=False, skip=False)  # pylint: disable=too-few-public-methods
 class WithOneMember(NamedTuple):
@@ -1479,3 +1515,18 @@ class TestArgsCallsWithOneMember(unittest.TestCase):
         object_repr = '{"val": "42", "to_skip": "skip"}'
         result = WithOneMemberSkipConv(**json.loads(object_repr))
         self.assertEqual(result.val, 42)
+
+
+@type_checked_constructor(convert=True)  # pylint: disable=too-few-public-methods
+class WithSequenceMember(NamedTuple):
+    """Some dummy class as a NamedTuple."""
+    val: Sequence[int]
+
+
+class TestListsAndSequences(unittest.TestCase):
+    """Tests conversions."""
+
+    def test_list_to_sequence(self) -> None:
+        """Should work."""
+        result = WithSequenceMember(val=[1, 2])
+        self.assertEqual(result.val, [1, 2])
